<?php

namespace Assetise\Scheduler\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Assetise\Scheduler\Actions\SchedulerExim;
use Assetise\Scheduler\Http\Requests\SchedulerEximRequest;

/**
 * Admin web controller class.
 */
class SchedulerEximController extends BaseController
{
    /**
     * Action controller function for scheduler.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(SchedulerEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = SchedulerExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('scheduler:scheduler.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('scheduler/scheduler/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('scheduler/scheduler/' . $exim))
                ->redirect();
        }
    }
}
