<?php

namespace Assetise\Scheduler\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Assetise\Scheduler\Http\Resources\SchedulerResource;
use Assetise\Scheduler\Http\Resources\SchedulersCollection;
use Assetise\Scheduler\Scopes\SchedulerPublicScope;
use Assetise\Scheduler\Models\Scheduler;

class SchedulerPublicController extends BaseController
{

    /**
     * Show scheduler's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Scheduler::pushScope(new RequestScope())
            ->pushScope(new SchedulerPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $schedulers = new SchedulersCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('scheduler::scheduler.names'))
            ->view('scheduler::public.scheduler.index')
            ->data(compact('schedulers', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show scheduler.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Scheduler::findBySlug($slug);
        $data = new SchedulerResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('scheduler::scheduler.name'))
            ->view('scheduler::public.scheduler.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
