<?php
namespace Assetise\Scheduler\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Assetise\Scheduler\Events\SchedulerAction as SchedulerActionEvent;
use Assetise\Scheduler\Models\Scheduler;

class SchedulerAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $scheduler;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param SchedulerActionEvent $scheduler
     */
    public function __construct(SchedulerActionEvent $scheduler)
    {
        $this->action = $event->action;
        $this->scheduler = $scheduler;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Scheduler Approved - ' . config('app.name'))
            ->view('scheduler::scheduler.email.action', ['data' => $this->scheduler]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
