<?php

namespace Assetise\Scheduler\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Assetise\Scheduler\Models\Scheduler;

class SchedulerPolicy
{

    use SchedulerAction;
    use SchedulerExim;
    use SchedulerReport;
    use SchedulerWorkflow;

    /**
     * Determine if the given user can view the scheduler.
     *
     * @param Authenticatable $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function view(Authenticatable $user, Scheduler $scheduler)
    {
        if ($authUser->canDo('scheduler.scheduler.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $scheduler->is_owner;
    }

    /**
     * Determine if the given user can create a scheduler.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('scheduler.scheduler.create');
    }

    /**
     * Determine if the given user can update the given scheduler.
     *
     * @param Authenticatable $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function update(Authenticatable $user, Scheduler $scheduler)
    {
        if ($user->canDo('scheduler.scheduler.edit') && $user->isAdmin()) {
            return true;
        }

        return $scheduler->is_owner;
    }

    /**
     * Determine if the given user can delete the given scheduler.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Scheduler $scheduler)
    {
        return $scheduler->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
